@@ -303,7 +303,7 @@ def doDescribeSkillGroupInfoList(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
-def doDescribeStaffInfoList(args, parsed_globals):
+def doDescribeCCCBuyInfoList(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
     if g_param[OptionsDefine.UseCVMRole.replace('-', '_')]:
@@ -328,11 +328,11 @@ def doDescribeStaffInfoList(args, parsed_globals):
     client = mod.CccClient(cred, g_param[OptionsDefine.Region], profile)
     client._sdkVersion += ("_CLI_" + __version__)
     models = MODELS_MAP[g_param[OptionsDefine.Version]]
-    model = models.DescribeStaffInfoListRequest()
+    model = models.DescribeCCCBuyInfoListRequest()
     model.from_json_string(json.dumps(args))
     start_time = time.time()
     while True:
-        rsp = client.DescribeStaffInfoList(model)
+        rsp = client.DescribeCCCBuyInfoList(model)
         result = rsp.to_json_string()
         try:
             json_obj = json.loads(result)
@@ -399,6 +399,54 @@ def doCreateStaff(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
+def doBindStaffSkillGroupList(args, parsed_globals):
+    g_param = parse_global_arg(parsed_globals)
+
+    if g_param[OptionsDefine.UseCVMRole.replace('-', '_')]:
+        cred = credential.CVMRoleCredential()
+    elif g_param[OptionsDefine.RoleArn.replace('-', '_')] and g_param[OptionsDefine.RoleSessionName.replace('-', '_')]:
+        cred = credential.STSAssumeRoleCredential(
+            g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.RoleArn.replace('-', '_')],
+            g_param[OptionsDefine.RoleSessionName.replace('-', '_')]
+        )
+    else:
+        cred = credential.Credential(
+            g_param[OptionsDefine.SecretId], g_param[OptionsDefine.SecretKey], g_param[OptionsDefine.Token]
+        )
+    http_profile = HttpProfile(
+        reqTimeout=60 if g_param[OptionsDefine.Timeout] is None else int(g_param[OptionsDefine.Timeout]),
+        reqMethod="POST",
+        endpoint=g_param[OptionsDefine.Endpoint],
+        proxy=g_param[OptionsDefine.HttpsProxy.replace('-', '_')]
+    )
+    profile = ClientProfile(httpProfile=http_profile, signMethod="HmacSHA256")
+    mod = CLIENT_MAP[g_param[OptionsDefine.Version]]
+    client = mod.CccClient(cred, g_param[OptionsDefine.Region], profile)
+    client._sdkVersion += ("_CLI_" + __version__)
+    models = MODELS_MAP[g_param[OptionsDefine.Version]]
+    model = models.BindStaffSkillGroupListRequest()
+    model.from_json_string(json.dumps(args))
+    start_time = time.time()
+    while True:
+        rsp = client.BindStaffSkillGroupList(model)
+        result = rsp.to_json_string()
+        try:
+            json_obj = json.loads(result)
+        except TypeError as e:
+            json_obj = json.loads(result.decode('utf-8'))  # python3.3
+        if not g_param[OptionsDefine.Waiter] or search(g_param['OptionsDefine.WaiterInfo']['expr'], json_obj) == g_param['OptionsDefine.WaiterInfo']['to']:
+            break
+        cur_time = time.time()
+        if cur_time - start_time >= g_param['OptionsDefine.WaiterInfo']['timeout']:
+            raise ClientError('Request timeout, wait `%s` to `%s` timeout, last request is %s' %
+            (g_param['OptionsDefine.WaiterInfo']['expr'], g_param['OptionsDefine.WaiterInfo']['to'],
+            search(g_param['OptionsDefine.WaiterInfo']['expr'], json_obj)))
+        else:
+            print('Inquiry result is %s.' % search(g_param['OptionsDefine.WaiterInfo']['expr'], json_obj))
+        time.sleep(g_param['OptionsDefine.WaiterInfo']['interval'])
+    FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
+
+
 def doUnbindStaffSkillGroupList(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
@@ -735,7 +783,7 @@ def doDescribeTelCallInfo(args, parsed_globals):
     FormatOutput.output("action", json_obj, g_param[OptionsDefine.Output], g_param[OptionsDefine.Filter])
 
 
-def doBindStaffSkillGroupList(args, parsed_globals):
+def doDescribeStaffInfoList(args, parsed_globals):
     g_param = parse_global_arg(parsed_globals)
 
     if g_param[OptionsDefine.UseCVMRole.replace('-', '_')]:
@@ -760,11 +808,11 @@ def doBindStaffSkillGroupList(args, parsed_globals):
     client = mod.CccClient(cred, g_param[OptionsDefine.Region], profile)
     client._sdkVersion += ("_CLI_" + __version__)
     models = MODELS_MAP[g_param[OptionsDefine.Version]]
-    model = models.BindStaffSkillGroupListRequest()
+    model = models.DescribeStaffInfoListRequest()
     model.from_json_string(json.dumps(args))
     start_time = time.time()
     while True:
-        rsp = client.BindStaffSkillGroupList(model)
+        rsp = client.DescribeStaffInfoList(model)
         result = rsp.to_json_string()
         try:
             json_obj = json.loads(result)
@@ -848,8 +896,9 @@ ACTION_MAP = {
     "CreateUserSig": doCreateUserSig,
     "DeleteStaff": doDeleteStaff,
     "DescribeSkillGroupInfoList": doDescribeSkillGroupInfoList,
-    "DescribeStaffInfoList": doDescribeStaffInfoList,
+    "DescribeCCCBuyInfoList": doDescribeCCCBuyInfoList,
     "CreateStaff": doCreateStaff,
+    "BindStaffSkillGroupList": doBindStaffSkillGroupList,
     "UnbindStaffSkillGroupList": doUnbindStaffSkillGroupList,
     "DescribeTelSession": doDescribeTelSession,
     "CreateSDKLoginToken": doCreateSDKLoginToken,
@@ -857,7 +906,7 @@ ACTION_MAP = {
     "DescribeCallInMetrics": doDescribeCallInMetrics,
     "DescribeStaffStatusMetrics": doDescribeStaffStatusMetrics,
     "DescribeTelCallInfo": doDescribeTelCallInfo,
-    "BindStaffSkillGroupList": doBindStaffSkillGroupList,
+    "DescribeStaffInfoList": doDescribeStaffInfoList,
     "DescribeTelCdr": doDescribeTelCdr,
 
 }
